@@ -27,6 +27,10 @@ function(...)
     ## compute target support
     support <- do.call(set_intersection, l)
 
+    ## handle empty supprt
+    if (gset_is_empty(support))
+        return(set())
+
     ## handle the "ordinary set" case
     if (all(sapply(l, gset_is_set)))
         return(support)
@@ -48,6 +52,10 @@ function(...)
     support <- cset(.set_intersection(.as.list(l), matchfun),
                     orderfun, matchfun)
 
+    ## handle empty supprt
+    if (cset_is_empty(support))
+        return(set())
+
     ## handle the "ordinary set" case
     if (all(sapply(l, gset_is_set)))
         return(support)
